Drive

Struct Drive 

pub struct Drive {
    pub drive_id: String,
    pub cache_type: Option<CacheType>,
    pub is_read_only: bool,
    pub is_root_device: bool,
    pub partuuid: Option<String>,
    pub path_on_host: String,
    pub rate_limiter: Option<Box<RateLimiter>>,
    pub io_engine: Option<IoEngine>,
}

Fields

drive_id: Stringcache_type: Option<CacheType>

Represents the caching strategy for the block device.

is_read_only: boolis_root_device: boolpartuuid: Option<String>

Represents the unique id of the boot partition of this device. It is optional and it will be taken into account only if the is_root_device field is true.

path_on_host: String

Host level path for the guest drive

rate_limiter: Option<Box<RateLimiter>>io_engine: Option<IoEngine>

Type of the IO engine used by the device. "Async" is supported on host kernels newer than 5.10.51.

Implementations

Source

impl Drive

pub fn new( drive_id: String, is_read_only: bool, is_root_device: bool, path_on_host: String, ) -> Drive